=== modified file 'plugin/blitzdb/ha_blitz.cc'
--- plugin/blitzdb/ha_blitz.cc	2010-11-03 16:54:55 +0000
+++ plugin/blitzdb/ha_blitz.cc	2010-11-07 04:38:53 +0000
@@ -168,6 +168,42 @@
   BlitzData blitz_table;
   uint32_t nkeys;
 
+  BlitzData dict;
+  int ecode;
+  /* Write the table definition to system table. */
+  if ((ecode = dict.open_system_table(from.getPath(), HDBOWRITER)) != 0)
+    return ecode;
+
+  drizzled::message::Table proto;
+  char *proto_string;
+  int proto_string_len;
+
+  proto_string = dict.get_system_entry(BLITZ_TABLE_PROTO_KEY.c_str(),
+                                       BLITZ_TABLE_PROTO_KEY.length(),
+                                       &proto_string_len);
+
+  if (proto_string == NULL) {
+    return ENOMEM;
+  }
+
+  if (!proto.ParseFromArray(proto_string, proto_string_len)) {
+    free(proto_string);
+    return HA_ERR_CRASHED_ON_USAGE;
+  }
+
+  free(proto_string);
+
+  proto.set_name(to.getTableName());
+  proto.set_schema(to.getSchemaName());
+  proto.set_catalog(to.getCatalogName());
+
+  if (!dict.write_table_definition(proto)) {
+    dict.close_system_table();
+    return HA_ERR_CRASHED_ON_USAGE;
+  }
+
+  dict.close_system_table();
+
   /* Find out the number of indexes in this table. This information
      is required because BlitzDB creates a file for each indexes.*/
   if (blitz_table.open_data_table(from.getPath().c_str(), HDBOREADER) != 0)

=== added file 'plugin/blitzdb/tests/r/bug621755-renametable-not-updating.result'
--- plugin/blitzdb/tests/r/bug621755-renametable-not-updating.result	1970-01-01 00:00:00 +0000
+++ plugin/blitzdb/tests/r/bug621755-renametable-not-updating.result	2010-11-07 04:27:56 +0000
@@ -0,0 +1,7 @@
+create table t5 (a int);
+alter table t5 engine=blitzdb;
+show create table t5;
+Table	Create Table
+t5	CREATE TABLE `t5` (
+  `a` INT DEFAULT NULL
+) ENGINE=BLITZDB COLLATE = utf8_general_ci

=== added file 'plugin/blitzdb/tests/t/bug621755-renametable-not-updating.test'
--- plugin/blitzdb/tests/t/bug621755-renametable-not-updating.test	1970-01-01 00:00:00 +0000
+++ plugin/blitzdb/tests/t/bug621755-renametable-not-updating.test	2010-11-07 04:27:56 +0000
@@ -0,0 +1,3 @@
+create table t5 (a int);
+alter table t5 engine=blitzdb;
+show create table t5;

